pub struct Extension {
pub id: String,
pub extension_path: String,
pub is_active: bool,
pub package_json: Value,
}Expand description
Extension representation
Fields
id: StringThe canonical extension identifier in the form of publisher.name
extension_path: StringThe absolute file path of the directory containing the extension
is_active: booltrue if the extension is enabled
package_json: ValueThe package.json object of the extension